@@ -5,9 +5,11 @@ import assert from 'assert';
 import { PassThrough } from 'stream';
 import nock from 'nock';
 import { spy } from 'sinon';
+import { humanStr } from '../dist/parse-time';
 
 
-const concat = (stream: PassThrough, callback: (err: Error, body: string) => void) => {
+nock.disableNetConnect();
+const concat = (stream: PassThrough, callback: (err: Error | null, body: string) => void) => {
   let body = '';
   stream.setEncoding('utf8');
   stream.on('data', (chunk: string) => { body += chunk; });
@@ -17,17 +19,20 @@ const concat = (stream: PassThrough, callback: (err: Error, body: string) => voi
 
 describe('m3u8stream', () => {
   let setTimeout = global.setTimeout;
-  before(() => { global.setTimeout = (fn, ms, ...args) => setTimeout(fn, 0, ...args); });
+  before(() => { global.setTimeout = process.nextTick as typeof global.setTimeout; });
   after(() => { global.setTimeout = setTimeout; });
 
   describe('Simple media playlist', () => {
-    it('Concatenates segments into stream', (done) => {
+    it('Concatenates segments into stream', done => {
       let scope = nock('http://media.example.com')
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname, 'playlists/simple.m3u8'))
-        .get('/first.ts').reply(200, 'one')
-        .get('/second.ts').reply(200, 'two')
-        .get('/third.ts').reply(200, 'three');
+        .get('/first.ts')
+        .reply(200, 'one')
+        .get('/second.ts')
+        .reply(200, 'two')
+        .get('/third.ts')
+        .reply(200, 'three');
       let stream = m3u8stream('http://media.example.com/playlist.m3u8');
       concat(stream, (err, body) => {
         assert.ifError(err);
@@ -37,14 +42,17 @@ describe('m3u8stream', () => {
       });
     });
 
-    it('Concatenates relative segments into stream', (done) => {
+    it('Concatenates relative segments into stream', done => {
       let scope = nock('http://media.example.com')
         .get('/playlist.m3u8')
         .replyWithFile(200,
           path.resolve(__dirname, 'playlists/simple_relative.m3u8'))
-        .get('/first.ts').reply(200, 'one')
-        .get('/second.ts').reply(200, 'two')
-        .get('/third.ts').reply(200, 'three');
+        .get('/first.ts')
+        .reply(200, 'one')
+        .get('/second.ts')
+        .reply(200, 'two')
+        .get('/third.ts')
+        .reply(200, 'three');
       let stream = m3u8stream('http://media.example.com/playlist.m3u8');
       concat(stream, (err, body) => {
         assert.ifError(err);
@@ -54,13 +62,16 @@ describe('m3u8stream', () => {
       });
     });
 
-    it('Tracks segment download progress', (done) => {
+    it('Tracks segment download progress', done => {
       let scope = nock('http://media.example.com')
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname, 'playlists/simple.m3u8'))
-        .get('/first.ts').reply(200, 'one')
-        .get('/second.ts').reply(200, 'two')
-        .get('/third.ts').reply(200, 'three');
+        .get('/first.ts')
+        .reply(200, 'one')
+        .get('/second.ts')
+        .reply(200, 'two')
+        .get('/third.ts')
+        .reply(200, 'three');
       let stream = m3u8stream('http://media.example.com/playlist.m3u8');
       let progress: [m3u8stream.Progress, number, number][] = [];
       stream.on('progress', (segment, total, downloaded) => {
@@ -92,22 +103,24 @@ describe('m3u8stream', () => {
         ]);
         done();
       });
-
     });
 
-    it('Forwards events from miniget', (done) => {
+    it('Forwards events from miniget', done => {
       let scope = nock('http://media.example.com')
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname, 'playlists/simple.m3u8'))
-        .get('/first.ts').reply(200, '1')
-        .get('/second.ts').reply(200, '2')
-        .get('/third.ts').reply(200, '3');
+        .get('/first.ts')
+        .reply(200, '1')
+        .get('/second.ts')
+        .reply(200, '2')
+        .get('/third.ts')
+        .reply(200, '3');
       let stream = m3u8stream('http://media.example.com/playlist.m3u8');
       let reqSpy = spy();
       let resSpy = spy();
       stream.on('request', reqSpy);
       stream.on('response', resSpy);
-      concat(stream, (err) => {
+      concat(stream, err => {
         assert.ifError(err);
         scope.done();
         assert.equal(reqSpy.callCount, 4);
@@ -117,24 +130,37 @@ describe('m3u8stream', () => {
     });
 
     describe('With `begin` set using relative format', () => {
-      it('Starts stream on segment that matches `begin`', (done) => {
+      it('Starts stream on segment that matches `begin`', done => {
         let scope = nock('https://twitch.tv')
           .get('/videos/sc.m3u8')
           .replyWithFile(200, path.resolve(__dirname,
             'playlists/twitch-1.1.m3u8'))
-          .get('/videos/3.ts').reply(200, 'the')
-          .get('/videos/4.ts').reply(200, 'big')
-          .get('/videos/5.ts').reply(200, 'brown')
-          .get('/videos/6.ts').reply(200, 'fox')
-          .get('/videos/7.ts').reply(200, 'jumped')
-          .get('/videos/8.ts').reply(200, 'over')
-          .get('/videos/9.ts').reply(200, 'the')
-          .get('/videos/10.ts').reply(200, 'lazy')
-          .get('/videos/11.ts').reply(200, 'dog')
-          .get('/videos/12.ts').reply(200, 'and')
-          .get('/videos/13.ts').reply(200, 'then')
-          .get('/videos/14.ts').reply(200, 'went')
-          .get('/videos/15.ts').reply(200, 'home');
+          .get('/videos/3.ts')
+          .reply(200, 'the')
+          .get('/videos/4.ts')
+          .reply(200, 'big')
+          .get('/videos/5.ts')
+          .reply(200, 'brown')
+          .get('/videos/6.ts')
+          .reply(200, 'fox')
+          .get('/videos/7.ts')
+          .reply(200, 'jumped')
+          .get('/videos/8.ts')
+          .reply(200, 'over')
+          .get('/videos/9.ts')
+          .reply(200, 'the')
+          .get('/videos/10.ts')
+          .reply(200, 'lazy')
+          .get('/videos/11.ts')
+          .reply(200, 'dog')
+          .get('/videos/12.ts')
+          .reply(200, 'and')
+          .get('/videos/13.ts')
+          .reply(200, 'then')
+          .get('/videos/14.ts')
+          .reply(200, 'went')
+          .get('/videos/15.ts')
+          .reply(200, 'home');
 
         let stream = m3u8stream('https://twitch.tv/videos/sc.m3u8', { begin: '30s' });
         concat(stream, (err, body) => {
@@ -153,7 +179,7 @@ describe('m3u8stream', () => {
             'and',
             'then',
             'went',
-            'home'
+            'home',
           ].join(''));
           done();
         });
@@ -162,34 +188,54 @@ describe('m3u8stream', () => {
   });
 
   describe('Live media playlist', () => {
-    it('Refresh after nearing end of segment list', (done) => {
+    it('Refresh after nearing end of segment list', done => {
       let scope = nock('https://priv.example.com')
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname,
           'playlists/live-2.1.m3u8'))
-        .get('/fileSequence2681.ts').reply(200, 'apple')
-        .get('/fileSequence2682.ts').reply(200, 'banana')
-        .get('/fileSequence2683.ts').reply(200, 'cherry')
-        .get('/fileSequence2684.ts').reply(200, 'durango')
-        .get('/fileSequence2685.ts').reply(200, 'eggfruit')
-        .get('/fileSequence2686.ts').reply(200, 'fig')
-        .get('/fileSequence2687.ts').reply(200, 'grape')
-        .get('/fileSequence2688.ts').reply(200, 'hackberry')
-        .get('/fileSequence2689.ts').reply(200, 'imbe')
-        .get('/fileSequence2690.ts').reply(200, 'java')
+        .get('/fileSequence2681.ts')
+        .reply(200, 'apple')
+        .get('/fileSequence2682.ts')
+        .reply(200, 'banana')
+        .get('/fileSequence2683.ts')
+        .reply(200, 'cherry')
+        .get('/fileSequence2684.ts')
+        .reply(200, 'durango')
+        .get('/fileSequence2685.ts')
+        .reply(200, 'eggfruit')
+        .get('/fileSequence2686.ts')
+        .reply(200, 'fig')
+        .get('/fileSequence2687.ts')
+        .reply(200, 'grape')
+        .get('/fileSequence2688.ts')
+        .reply(200, 'hackberry')
+        .get('/fileSequence2689.ts')
+        .reply(200, 'imbe')
+        .get('/fileSequence2690.ts')
+        .reply(200, 'java')
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname,
           'playlists/live-2.2.m3u8'))
-        .get('/fileSequence2691.ts').reply(200, 'kiwi')
-        .get('/fileSequence2692.ts').reply(200, 'lime')
-        .get('/fileSequence2693.ts').reply(200, 'melon')
-        .get('/fileSequence2694.ts').reply(200, 'nut')
-        .get('/fileSequence2695.ts').reply(200, 'orange')
-        .get('/fileSequence2696.ts').reply(200, 'pear')
-        .get('/fileSequence2697.ts').reply(200, 'melon')
-        .get('/fileSequence2698.ts').reply(200, 'quince')
-        .get('/fileSequence2699.ts').reply(200, 'raspberry')
-        .get('/fileSequence2700.ts').reply(200, 'strawberry');
+        .get('/fileSequence2691.ts')
+        .reply(200, 'kiwi')
+        .get('/fileSequence2692.ts')
+        .reply(200, 'lime')
+        .get('/fileSequence2693.ts')
+        .reply(200, 'melon')
+        .get('/fileSequence2694.ts')
+        .reply(200, 'nut')
+        .get('/fileSequence2695.ts')
+        .reply(200, 'orange')
+        .get('/fileSequence2696.ts')
+        .reply(200, 'pear')
+        .get('/fileSequence2697.ts')
+        .reply(200, 'melon')
+        .get('/fileSequence2698.ts')
+        .reply(200, 'quince')
+        .get('/fileSequence2699.ts')
+        .reply(200, 'raspberry')
+        .get('/fileSequence2700.ts')
+        .reply(200, 'strawberry');
 
       let stream = m3u8stream('https://priv.example.com/playlist.m3u8');
       concat(stream, (err, body) => {
@@ -215,19 +261,19 @@ describe('m3u8stream', () => {
           'melon',
           'quince',
           'raspberry',
-          'strawberry'
+          'strawberry',
         ].join(''));
         done();
       });
     });
 
-    it('Stops on error getting playlist', (done) => {
+    it('Stops on error getting playlist', done => {
       let scope = nock('http://mysite.com')
         .get('/pl.m3u8')
         .replyWithError('Nooo');
       let stream = m3u8stream('http://mysite.com/pl.m3u8', {
         requestOptions: { maxRetries: 0 } });
-      stream.on('error', (err) => {
+      stream.on('error', err => {
         scope.done();
         assert.equal(err.message, 'Nooo');
         done();
@@ -237,20 +283,23 @@ describe('m3u8stream', () => {
       });
     });
 
-    it('Stops on error refreshing playlist', (done) => {
+    it('Stops on error refreshing playlist', done => {
       let scope = nock('https://priv.example.com')
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname,
           'playlists/live-1.1.m3u8'))
-        .get('/fileSequence2681.ts').reply(200, 'one')
-        .get('/fileSequence2682.ts').reply(200, 'two')
-        .get('/fileSequence2683.ts').reply(200, 'three')
+        .get('/fileSequence2681.ts')
+        .reply(200, 'one')
+        .get('/fileSequence2682.ts')
+        .reply(200, 'two')
+        .get('/fileSequence2683.ts')
+        .reply(200, 'three')
         .get('/playlist.m3u8')
         .replyWithError('uh oh');
 
       let stream = m3u8stream('https://priv.example.com/playlist.m3u8', {
         requestOptions: { maxRetries: 0 } });
-      stream.on('error', (err) => {
+      stream.on('error', err => {
         scope.done();
         assert.equal(err.message, 'uh oh');
         done();
@@ -260,18 +309,20 @@ describe('m3u8stream', () => {
       });
     });
 
-    it('Stops on error getting a segment', (done) => {
+    it('Stops on error getting a segment', done => {
       let scope = nock('https://priv.example.com')
         .get('/playme.m3u8')
         .replyWithFile(200, path.resolve(__dirname,
           'playlists/live-1.1.m3u8'))
-        .get('/fileSequence2681.ts').reply(200, 'hello')
-        .get('/fileSequence2682.ts').replyWithError('bad segment');
+        .get('/fileSequence2681.ts')
+        .reply(200, 'hello')
+        .get('/fileSequence2682.ts')
+        .replyWithError('bad segment');
       let stream = m3u8stream('https://priv.example.com/playme.m3u8', {
         chunkReadahead: 1,
         requestOptions: { maxRetries: 0 },
       });
-      stream.on('error', (err) => {
+      stream.on('error', err => {
         assert.equal(err.message, 'bad segment');
         scope.done();
         done();
@@ -281,22 +332,27 @@ describe('m3u8stream', () => {
       });
     });
 
-    it('Handles retrieving same live playlist twice', (done) => {
+    it('Handles retrieving same live playlist twice', done => {
       let scope = nock('https://priv.example.com')
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname,
           'playlists/live-1.1.m3u8'))
-        .get('/fileSequence2681.ts').reply(200, 'apple')
-        .get('/fileSequence2682.ts').reply(200, 'banana')
-        .get('/fileSequence2683.ts').reply(200, 'cherry')
+        .get('/fileSequence2681.ts')
+        .reply(200, 'apple')
+        .get('/fileSequence2682.ts')
+        .reply(200, 'banana')
+        .get('/fileSequence2683.ts')
+        .reply(200, 'cherry')
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname,
           'playlists/live-1.1.m3u8'))
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname,
           'playlists/live-1.2.m3u8'))
-        .get('/fileSequence2684.ts').reply(200, 'fig')
-        .get('/fileSequence2685.ts').reply(200, 'grape');
+        .get('/fileSequence2684.ts')
+        .reply(200, 'fig')
+        .get('/fileSequence2685.ts')
+        .reply(200, 'grape');
 
       let stream = m3u8stream('https://priv.example.com/playlist.m3u8');
       concat(stream, (err, body) => {
@@ -307,34 +363,41 @@ describe('m3u8stream', () => {
           'banana',
           'cherry',
           'fig',
-          'grape'
+          'grape',
         ].join(''));
         done();
       });
-
     });
 
     describe('With dated segments', () => {
       describe('With `begin` set to now', () => {
-        it('Starts stream on segment that matches `begin`', (done) => {
+        it('Starts stream on segment that matches `begin`', done => {
           let scope = nock('https://yt.com')
             .get('/playlist.m3u8')
             .replyWithFile(200, path.resolve(__dirname,
               'playlists/youtube-live-1.1.m3u8'))
-            .get('/fileSequence0005.ts').reply(200, '05')
-            .get('/fileSequence0006.ts').reply(200, '06')
-            .get('/fileSequence0007.ts').reply(200, '07')
-            .get('/fileSequence0008.ts').reply(200, '08')
+            .get('/fileSequence0005.ts')
+            .reply(200, '05')
+            .get('/fileSequence0006.ts')
+            .reply(200, '06')
+            .get('/fileSequence0007.ts')
+            .reply(200, '07')
+            .get('/fileSequence0008.ts')
+            .reply(200, '08')
             .get('/playlist.m3u8')
             .replyWithFile(200, path.resolve(__dirname,
               'playlists/youtube-live-1.2.m3u8'))
-            .get('/fileSequence0009.ts').reply(200, '09')
-            .get('/fileSequence0010.ts').reply(200, '10')
-            .get('/fileSequence0011.ts').reply(200, '11')
-            .get('/fileSequence0012.ts').reply(200, '12');
+            .get('/fileSequence0009.ts')
+            .reply(200, '09')
+            .get('/fileSequence0010.ts')
+            .reply(200, '10')
+            .get('/fileSequence0011.ts')
+            .reply(200, '11')
+            .get('/fileSequence0012.ts')
+            .reply(200, '12');
 
           let stream = m3u8stream('https://yt.com/playlist.m3u8', {
-            begin: Date.now()
+            begin: Date.now(),
           });
           concat(stream, (err, body) => {
             assert.ifError(err);
@@ -347,7 +410,7 @@ describe('m3u8stream', () => {
               '09',
               '10',
               '11',
-              '12'
+              '12',
             ].join(''));
             done();
           });
@@ -355,24 +418,34 @@ describe('m3u8stream', () => {
       });
 
       describe('With `begin` set using relative format', () => {
-        it('Starts stream on segment that matches `begin`', (done) => {
+        it('Starts stream on segment that matches `begin`', done => {
           let scope = nock('https://yt.com')
             .get('/playlist.m3u8')
             .replyWithFile(200, path.resolve(__dirname,
               'playlists/youtube-live-1.1.m3u8'))
-            .get('/fileSequence0003.ts').reply(200, '03')
-            .get('/fileSequence0004.ts').reply(200, '04')
-            .get('/fileSequence0005.ts').reply(200, '05')
-            .get('/fileSequence0006.ts').reply(200, '06')
-            .get('/fileSequence0007.ts').reply(200, '07')
-            .get('/fileSequence0008.ts').reply(200, '08')
+            .get('/fileSequence0003.ts')
+            .reply(200, '03')
+            .get('/fileSequence0004.ts')
+            .reply(200, '04')
+            .get('/fileSequence0005.ts')
+            .reply(200, '05')
+            .get('/fileSequence0006.ts')
+            .reply(200, '06')
+            .get('/fileSequence0007.ts')
+            .reply(200, '07')
+            .get('/fileSequence0008.ts')
+            .reply(200, '08')
             .get('/playlist.m3u8')
             .replyWithFile(200, path.resolve(__dirname,
               'playlists/youtube-live-1.2.m3u8'))
-            .get('/fileSequence0009.ts').reply(200, '09')
-            .get('/fileSequence0010.ts').reply(200, '10')
-            .get('/fileSequence0011.ts').reply(200, '11')
-            .get('/fileSequence0012.ts').reply(200, '12');
+            .get('/fileSequence0009.ts')
+            .reply(200, '09')
+            .get('/fileSequence0010.ts')
+            .reply(200, '10')
+            .get('/fileSequence0011.ts')
+            .reply(200, '11')
+            .get('/fileSequence0012.ts')
+            .reply(200, '12');
 
           let stream = m3u8stream('https://yt.com/playlist.m3u8', { begin: '10s' });
           concat(stream, (err, body) => {
@@ -388,7 +461,7 @@ describe('m3u8stream', () => {
               '09',
               '10',
               '11',
-              '12'
+              '12',
             ].join(''));
             done();
           });
@@ -398,7 +471,7 @@ describe('m3u8stream', () => {
 
     describe('Destroy stream', () => {
       describe('Right away', () => {
-        it('Ends stream right away with no data', (done) => {
+        it('Ends stream right away with no data', done => {
           let stream = m3u8stream('https://whatever.com/playlist.m3u8');
           concat(stream, (err, body) => {
             assert.ifError(err);
@@ -410,16 +483,21 @@ describe('m3u8stream', () => {
       });
 
       describe('In the middle of the segments list', () => {
-        it('Stops stream from emitting more data and ends it', (done) => {
+        it('Stops stream from emitting more data and ends it', done => {
           let scope = nock('https://priv.example.com')
             .get('/playlist.m3u8')
             .replyWithFile(200, path.resolve(__dirname,
               'playlists/live-2.1.m3u8'))
-            .get('/fileSequence2681.ts').reply(200, 'apple')
-            .get('/fileSequence2682.ts').reply(200, 'banana')
-            .get('/fileSequence2683.ts').reply(200, 'cherry')
-            .get('/fileSequence2684.ts').reply(200, 'durango')
-            .get('/fileSequence2685.ts').reply(200, 'whatever');
+            .get('/fileSequence2681.ts')
+            .reply(200, 'apple')
+            .get('/fileSequence2682.ts')
+            .reply(200, 'banana')
+            .get('/fileSequence2683.ts')
+            .reply(200, 'cherry')
+            .get('/fileSequence2684.ts')
+            .reply(200, 'durango')
+            .get('/fileSequence2685.ts')
+            .reply(200, 'whatever');
           let stream = m3u8stream('https://priv.example.com/playlist.m3u8', {
             chunkReadahead: 1,
           });
@@ -446,21 +524,31 @@ describe('m3u8stream', () => {
   });
 
   describe('DASH MPD playlist', () => {
-    it('Concatenates egments into stream', (done) => {
+    it('Concatenates egments into stream', done => {
       let scope = nock('https://videohost.com')
         .get('/playlist.mpd')
         .replyWithFile(200, path.resolve(__dirname,
           'playlists/multi-representation.mpd'))
-        .get('/134/0001.ts').reply(200, '01')
-        .get('/134/0002.ts').reply(200, '02')
-        .get('/134/0003.ts').reply(200, '03')
-        .get('/134/0004.ts').reply(200, '04')
-        .get('/134/0005.ts').reply(200, '05')
-        .get('/134/0006.ts').reply(200, '06')
-        .get('/134/0007.ts').reply(200, '07')
-        .get('/134/0008.ts').reply(200, '08')
-        .get('/134/0009.ts').reply(200, '09')
-        .get('/134/0010.ts').reply(200, '10');
+        .get('/134/0001.ts')
+        .reply(200, '01')
+        .get('/134/0002.ts')
+        .reply(200, '02')
+        .get('/134/0003.ts')
+        .reply(200, '03')
+        .get('/134/0004.ts')
+        .reply(200, '04')
+        .get('/134/0005.ts')
+        .reply(200, '05')
+        .get('/134/0006.ts')
+        .reply(200, '06')
+        .get('/134/0007.ts')
+        .reply(200, '07')
+        .get('/134/0008.ts')
+        .reply(200, '08')
+        .get('/134/0009.ts')
+        .reply(200, '09')
+        .get('/134/0010.ts')
+        .reply(200, '10');
       let stream = m3u8stream('https://videohost.com/playlist.mpd', {
         id: '134',
       });
@@ -477,7 +565,7 @@ describe('m3u8stream', () => {
           '07',
           '08',
           '09',
-          '10'
+          '10',
         ].join(''));
         done();
       });
@@ -485,28 +573,37 @@ describe('m3u8stream', () => {
   });
 
   describe('m3u8 playlist with ranges', () => {
-    it('Makes ranged requests', (done) => {
+    it('Makes ranged requests', done => {
       let filename = path.resolve(__dirname, 'playlists/main.mp4');
-      const replyWithRange = function(this: nock.ReplyFnContext) {
+      function replyWithRange(this: nock.ReplyFnContext) {
+        /* eslint no-invalid-this: off */
         const range = this.req.headers.range;
         assert.ok(range);
         const rangeMatch = range.match(/bytes=(\d+)-(\d+)/);
+        if (!rangeMatch) {
+          throw Error(`Bad range: ${range}`);
+        }
         return fs.createReadStream(filename, {
           start: parseInt(rangeMatch[1]), end: parseInt(rangeMatch[2]),
         });
-      };
+      }
       let scope = nock('https://somethingsomething.fyi')
         .get('/playlist.m3u8')
         .replyWithFile(200, path.resolve(__dirname,
           'playlists/x-byterange-1.m3u8'))
-        .get('/main.mp4').reply(200, replyWithRange)
-        .get('/main.mp4').reply(200, replyWithRange)
-        .get('/main.mp4').reply(200, replyWithRange)
-        .get('/main.mp4').reply(200, replyWithRange)
-        .get('/main.mp4').reply(200, replyWithRange);
+        .get('/main.mp4')
+        .reply(200, replyWithRange)
+        .get('/main.mp4')
+        .reply(200, replyWithRange)
+        .get('/main.mp4')
+        .reply(200, replyWithRange)
+        .get('/main.mp4')
+        .reply(200, replyWithRange)
+        .get('/main.mp4')
+        .reply(200, replyWithRange);
       let stream = m3u8stream('https://somethingsomething.fyi/playlist.m3u8');
       let segments: m3u8stream.Progress[] = [];
-      stream.on('progress', (segment) => segments.push(segment));
+      stream.on('progress', segment => segments.push(segment));
       concat(stream, (err, body) => {
         assert.ifError(err);
         scope.done();
@@ -533,9 +630,13 @@ describe('m3u8stream', () => {
       assert.throws(() => {
         m3u8stream('http://media.example.com/playlist.m3u8', {
           // @ts-ignore
-          parser: 'baaaaad'
+          parser: 'baaaaad',
         });
       }, /parser '\w+' not supported/);
     });
   });
+
+  describe('Exposes parse-time', () => {
+    assert.equal(m3u8stream.parseTimestamp, humanStr);
+  });
 });
